# RavenDB Cloud API Node.js Client

[RavenDB Cloud](https://cloud.ravendb.net) delivers the world's leading [NoSQL document database](https://ravendb.net) for modern applications as a fully automated cloud service run by the same developers that build and maintain the database engine. Communicate with our cloud programmatically and automate the actions you perform on your [RavenDB Cloud](https://cloud.ravendb.net) products.

## Install

```
npm install --save ravendb-cloud
```

## Use

```javascript
import { ApiClient } from "ravendb-cloud";

const client = new ApiClient({ 
    apiKey: "RVDB-XXXXXXXXXXXXXXXXXXXXXXXXXX" 
});

const createProduct = new ProductCreateRequest({
    displayName: "Fancy",
    subdomainName: "fancy",
    cloudProvider: "Aws",
    region: "us-east-1",
    tier: "Development",
    instanceTypeName: "Dev10",
    storageTypeName: "SsdStandard",
    diskSize: 15,
    releaseChannel: "Stable42",
    allowedIps: ["0.0.0.0/0"]
});

const response = await client.products.create(req);
// ProductCreateResponse { productId: '1234-B' }

const listResponse = await client.products.list();
// ...

```

# OpenAPI

RavenDB Cloud OpenAPI definition:

- [Swagger JSON](https://api.cloud.ravendb.net/api/v1/swagger.json)

- [Swagger UI](https://api.cloud.ravendb.net/swagger/index.html)

# Bugs

Bugs can be reported on [Hibernating Rhinos' YouTrack](https://issues.hibernatingrhinos.com/).
